import{j as e}from"./app.js";import{a as d,u as i,f as c,c as m}from"./table.js";function u({data:l,columns:s,getRowKey:o}){const r=i({data:l,columns:s,getCoreRowModel:m()});return e.jsx("div",{className:"table-wrapper",children:e.jsxs("table",{className:"responsive-table",children:[e.jsx("thead",{children:r.getHeaderGroups().map(t=>e.jsx("tr",{children:t.headers.map(a=>e.jsx("th",{children:a.isPlaceholder?null:c(a.column.columnDef.header,a.getContext())},a.id))},t.id))}),e.jsx("tbody",{children:r.getRowModel().rows.map(t=>{const a=o?o(t.original):t.id;return e.jsx("tr",{children:t.getVisibleCells().map(n=>e.jsx("td",{"data-label":String(n.column.columnDef.header),children:c(n.column.columnDef.cell,n.getContext())},n.id))},a)})})]})})}const h=d.memo(u,(l,s)=>l.data===s.data&&l.columns===s.columns);export{h as S};
//# sourceMappingURL=StableTable.js.map
